@@ -1,6 +1,7 @@
 import errno
 import logging
 import os
+from threading import Thread
 
 import zmq
 from zmq.eventloop import ioloop
@@ -71,7 +72,7 @@ class Arbiter(object):
         for any command from a client and that watches all the
         processes and restarts them if needed.
         """
-        logger.info("Starting master on pid %s" % self.pid)
+        logger.info("Starting master on pid %s", self.pid)
 
         self.initialize()
 
@@ -86,9 +87,9 @@ class Arbiter(object):
         # initialize processes
         logger.debug('Initializing watchers')
         for watcher in self.watchers:
-            watcher.manage_processes()
+            watcher.start()
 
-        logger.debug('Arbiter now waiting for commands')
+        logger.info('Arbiter now waiting for commands')
         while True:
             try:
                 self.loop.start()
@@ -106,7 +107,7 @@ class Arbiter(object):
         self.ctrl.stop()
         self.evpub_socket.close()
 
-    def stop(self, graceful=False, destroy_context=True):
+    def stop(self, graceful=False):
         if self.alive:
             self.stop_watchers(graceful=graceful, stop_alive=True)
         self.loop.stop()
@@ -192,7 +193,7 @@ class Arbiter(object):
 
         - **name**: name of the watcher to delete
         """
-        logger.debug('Deleting %r watcher' % name)
+        logger.debug('Deleting %r watcher', name)
 
         # remove the watcher from the list
         watcher = self._watchers_names.pop(name)
@@ -207,6 +208,7 @@ class Arbiter(object):
 
     def stop_watchers(self, graceful=True, stop_alive=False):
         if stop_alive:
+            logger.info('Arbiter exiting')
             if not self.alive:
                 return
 
@@ -214,3 +216,24 @@ class Arbiter(object):
 
         for watcher in self.watchers:
             watcher.stop(graceful=graceful)
+
+
+class ThreadedArbiter(Arbiter, Thread):
+
+    def __init__(self, watchers, endpoint, pubsub_endpoint, check_delay=1.,
+                 prereload_fn=None, context=None, loop=None,
+                 check_flapping=True):
+        Thread.__init__(self)
+        Arbiter.__init__(self, watchers, endpoint, pubsub_endpoint,
+                         check_delay, prereload_fn, context, loop,
+                         check_flapping)
+
+    def start(self):
+        return Thread.start(self)
+
+    def run(self):
+        return Arbiter.start(self)
+
+    def stop(self):
+        Arbiter.stop(self)
+        self.join()
