@@ -1,6 +1,5 @@
 import sys
 import argparse
-import ConfigParser
 import os
 import logging
 import resource
@@ -28,20 +27,6 @@ LOG_FMT = r"%(asctime)s [%(process)d] [%(levelname)s] %(message)s"
 LOG_DATE_FMT = r"%Y-%m-%d %H:%M:%S"
 
 
-class DefaultConfigParser(ConfigParser.ConfigParser):
-    def dget(self, section, option, default=None, type=str):
-        if not self.has_option(section, option):
-            return default
-        if type is str:
-            return self.get(section, option)
-        elif type is int:
-            return self.getint(section, option)
-        elif type is bool:
-            return self.getboolean(section, option)
-        else:
-            raise NotImplementedError()
-
-
 def get_maxfd():
     maxfd = resource.getrlimit(resource.RLIMIT_NOFILE)[1]
     if (maxfd == resource.RLIM_INFINITY):
@@ -61,10 +46,9 @@ except ImportError:
                 pass
 
 
+# http://www.svbug.com/documentation/comp.unix.programmer-FAQ/faq_2.html#SEC16
 def daemonize():
-    """\
-    Standard daemonization of a process.
-    http://www.svbug.com/documentation/comp.unix.programmer-FAQ/faq_2.html#SEC16
+    """Standard daemonization of a process.
     """
     #if not 'CIRCUS_PID' in os.environ:
     if os.fork():
@@ -84,7 +68,7 @@ def daemonize():
 
 
 def main():
-    parser = argparse.ArgumentParser(description='Run some shows.')
+    parser = argparse.ArgumentParser(description='Run some watchers.')
     parser.add_argument('config', help='configuration file')
 
     # XXX we should be able to add all these options in the config file as well
@@ -97,8 +81,7 @@ def main():
     parser.add_argument('--pidfile', dest='pidfile')
 
     args = parser.parse_args()
-    cfg = DefaultConfigParser()
-    cfg.read(args.config)
+    cfg, cfg_files_read = util.read_config(args.config)
 
     if args.daemonize:
         daemonize()
@@ -125,20 +108,21 @@ def main():
     h.setFormatter(fmt)
     logger.addHandler(h)
 
-    # Initialize shows to manage
+    logger.debug('Loaded config files %s' % str(cfg_files_read))
+
+    # Initialize watchers to manage
     watchers = []
     for section in cfg.sections():
-        if section.startswith("show:"):
-            name = section.split("show:", 1)[1]
+        if section.startswith("watcher:"):
+            name = section.split("watcher:", 1)[1]
 
             cmd = cfg.get(section, 'cmd')
             args = cfg.dget(section, 'args', '')
-            if args:
-                cmd = "%s %s" % (cmd, args)
 
             numprocesses = cfg.dget(section, 'numprocesses', 1, int)
             warmup_delay = cfg.dget(section, 'warmup_delay', 0, int)
 
+            executable = cfg.dget(section, 'executable', None, str)
             working_dir = cfg.dget(section, 'working_dir')
             shell = cfg.dget(section, 'shell', False, bool)
             uid = cfg.dget(section, 'uid')
@@ -150,11 +134,19 @@ def main():
             max_retry = cfg.dget(section, "max_retry", 5, int)
             graceful_timeout = cfg.dget(section, "graceful_timeout", 30, int)
 
-            watcher = Watcher(name, cmd, numprocesses=numprocesses,
+            rlimits = {}
+            for cfg_name, cfg_value in cfg.items(section):
+                if cfg_name.startswith('rlimit_'):
+                    limit = cfg_name[7:]
+                    rlimits[limit] = int(cfg_value)
+
+            watcher = Watcher(name, cmd, args=args, executable=executable,
+                        numprocesses=numprocesses,
                         warmup_delay=warmup_delay, working_dir=working_dir,
                         shell=shell, uid=uid, gid=gid, send_hup=send_hup,
                         times=times, within=within, retry_in=retry_in,
-                        max_retry=max_retry, graceful_timeout=graceful_timeout)
+                        max_retry=max_retry, graceful_timeout=graceful_timeout,
+                        rlimits=rlimits)
 
             watchers.append(watcher)
 
