@@ -1,8 +1,10 @@
+import ConfigParser
 from datetime import timedelta
 import grp
 import os
 import pwd
 import fcntl
+import fnmatch
 from functools import wraps
 
 from psutil.error import AccessDenied, NoSuchProcess
@@ -12,6 +14,20 @@ from circus import logger
 _SYMBOLS = ('K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y')
 
 
+class DefaultConfigParser(ConfigParser.ConfigParser):
+    def dget(self, section, option, default=None, type=str):
+        if not self.has_option(section, option):
+            return default
+        if type is str:
+            return self.get(section, option)
+        elif type is int:
+            return self.getint(section, option)
+        elif type is bool:
+            return self.getboolean(section, option)
+        else:
+            raise NotImplementedError()
+
+
 def get_working_dir():
     """Returns current path, try to use PWD env first"""
     try:
@@ -119,7 +135,7 @@ def to_uid(name):
         try:
             pwd.getpwuid(name)
             return name
-        except KeyError:
+        except (KeyError, OverflowError):
             raise ValueError("%r isn't a valid user id" % name)
 
     if not isinstance(name, str):
@@ -140,7 +156,7 @@ def to_gid(name):
         try:
             grp.getgrgid(name)
             return name
-        except KeyError:
+        except (KeyError, OverflowError):
             raise ValueError("No such group: %r" % name)
 
     if not isinstance(name, str):
@@ -198,3 +214,25 @@ def convert_opt(key, val):
         else:
             val = str(val)
     return val
+
+
+def read_config(config_path):
+    cfg = DefaultConfigParser()
+    with open(config_path) as f:
+        cfg.readfp(f)
+    cfg_files_read = [config_path]
+
+    # load included config files
+    includes = []
+    for include_file in cfg.dget('circus', 'include', '').split():
+        includes.append(include_file)
+
+    for include_dir in cfg.dget('circus', 'include_dir', '').split():
+        for root, dirnames, filenames in os.walk(include_dir):
+            for filename in fnmatch.filter(filenames, '*.ini'):
+                cfg_file = os.path.join(root, filename)
+                includes.append(cfg_file)
+
+    cfg_files_read.extend(cfg.read(includes))
+
+    return cfg, cfg_files_read
